#!/usr/bin/perl

# bin a set of simulated visibilities using the bin_vis program
# Klaus Maisinger, Sep-2001

$runcmd="nice -10";
$madcowpath="../madcow/";
$executable=$madcowpath."f77/bin_vis";
$tmpfile="binvis.input";

$ranseed=345;
$nfields=3;
@outfile = ( "VSA1", "VSA1A", "VSA1B" );
$nsim=1;
$usenoise=1;
$shiftpos=1;
$mirror=1;
@uvcells=(2,3,4);
#@uvcells=(1,2,3,5,7);
$numcells=@uvcells;

for ($i = 0; $i < $nfields; $i++) {
#    run_binvis($outfile[$i]."_0", $numcells, @uvcells);
    for ($j = 0; $j < $nsim; $j++) {
	run_binvis($outfile[$i]."_".$ranseed."_".($j+1), $numcells, @uvcells);
    }
}

sub run_binvis() {
    my $nameprefix=shift(@_);
    my $numbins=shift(@_);
    my @uvcell=@_;
    my $i;
    my @c=("n","y");
    my @args=("/bin/sh","-tc",$runcmd." ".$executable." < ".$tmpfile);

    if (!(-e $executable)) {
	die "Executable ",$executable," does not exist.\n";
    }

    open(OUTFILE, ">".$tmpfile);

    # input visibilities file name:
    print OUTFILE  $nameprefix.".vis", "\n";

    # Graphics device/type (? to see list, default /xwin):  
    print OUTFILE "/null", "\n";

    # Bin these data (1) or not (0):
    print OUTFILE 1, "\n";

    for ($i = 0; $i < $numbins; $i++) {

	# uv cell size (wavelengths)? 
	print OUTFILE $uvcell[$i], "\n";
    
	# Use noise estimates in file (1) or calculate from data (0): 
	print OUTFILE $usenoise, "\n";
	
	if ($usenoise==0) {
	    # Input minimum no. of points per bin:
	    print OUTFILE 10, "\n";
	    
	}
	else {
	    # Are noise estimates in file on Re/Im part (1) or modulus (0):
	    print OUTFILE 1, "\n";
	}

	# Output noise on Re/Im part (1) or modulus (0): 
	print OUTFILE 1, "\n";
	
	# Shift nominal bin positions (1) or not (0):
	print OUTFILE $shiftpos, "\n";

	# Mirror uv-plane (1) or not (0):
	print OUTFILE $mirror, "\n";

	# Write out binned values (1) or not (0): 
	print OUTFILE 0, "\n";

        # output file name (.vbn added)
	print OUTFILE $nameprefix."_".$uvcell[$i].$c[$usenoise].$c[$shiftpos].$c[$mirror], "\n";

	# Re-bin these data (1) or not (0):
	if ($i == $numbins-1) {
	    print OUTFILE 0, "\n";
	}
	else {
	    print OUTFILE 1, "\n";
	}
    }
    close OUTFILE;
    system(@args);
}

