#!/usr/bin/perl

# analyse simulated data using the vsaeigen program
# Klaus Maisinger, Sep-2001

$runcmd="nice -19";
$madcowpath="../madcow/";
$executable=$madcowpath."eigenlike";
$tmpfile="eigenlike.input";

$refreq=30;
$ranseed=345;
@ra= ( "00 20 00.00", "00 07 20.60", "00 12 50.00" );
@dec= ( "30 00 00.0", "30 16 30.0", "27 48 00.0" );
@outprefix = ( "VSA1", "VSA1A", "VSA1B" );
$nfreq=1;
my $nfields=3;
@freq=(34.1, 34.1, 34.1);
$gaussian_beam=1;
@fwhm=(4.6, 4.6, 4.6);
#@beam=("../gaussian34.1_1.79.fits");
#$bw=1.5;
#$nsub=1;
$nsim=1;
$noisescale=1;
$cmax=2.e-9;
$nsteps=201;
$writeflag=1;
$sparse=0;
$semiexact=1;
# bin_vis parameters
@uvcells=(4,3,2);
#@uvcells=(5);
$usenoise=1;
$shiftpos=1;
$mirror=1;


my $fieldno = 0, $simno = 1, $cellno = 0;

# loop over fields, gridding, and random simulations
$cellmax=@uvcells;
for ($fieldno = 0; $fieldno < $nfields; $fieldno++) {
    my $tmp;

    for ($simno = 1; $simno <= $nsim; $simno++) {
	for ($cellno = 0; $cellno < $cellmax; $cellno++) {
	    run_vsaeigen();
	}
    }
    # use next field; make previous field last element of the list
    $tmp = shift @outprefix; push @outprefix, $tmp;
    $tmp = shift @ra;        push @ra, $tmp;
    $tmp = shift @dec;       push @dec, $tmp;
}



sub run_vsaeigen() {
    my $i, $j;
    my @c=("n","y");
    my @args=("/bin/sh", "-tc", $runcmd." ".$executable." ".$tmpfile);

    if (!(-e $executable)) {
	die "Executable ",$executable," does not exist.\n";
    }

    open(OUTFILE, ">".$tmpfile);

    # Input number of observed datasets: 
    print OUTFILE "NFREQ \t", $nfreq,  "\n";
    
    # Input observing frequencies (GHz): 
    for ($i = 0; $i < $nfreq; $i++) {
	print OUTFILE "FREQ",$i+1," \t",$freq[$i], "\n";
    }

    # Enter RA (h min s) and DEC (deg min s) of field centre: 
    for ($i = 0; $i < $nfreq; $i++) {
	print OUTFILE "RA",$i+1," \t",$ra[$i], "\n";
	print OUTFILE "DEC",$i+1," \t",$dec[$i], "\n";
    }

    # Input FWHM of primary beam at each frequency (degrees):
    for ($i = 0; $i < $nfreq; $i++) {
	print OUTFILE "FWHM",$i+1," \t",$fwhm[$i], "\n";
    }

    # Input frequency for calculation (GHz):
    print OUTFILE  "REFFREQ \t",$refreq, "\n";

    # Input visibilities data file for each frequency:
    for ($i = 0; $i < $nfreq; $i++) {
	print OUTFILE "DATAFN",$i+1," \t", $outprefix[$i]."_".$ranseed."_".$simno."_".$uvcells[$cellno].$c[$usenoise].$c[$shiftpos].$c[$mirror].".vbn", "\n";
    }

    # Use automatic u-range and bin width above? (0 - no, 1 -yes):
    print OUTFILE "UVAUTOFLAG \t",1, "\n";


    # Input range of l^2 C_l/2pi for CMB:
    print OUTFILE "CPSMIN \t", 0.,"\n";
    print OUTFILE "CPSMAX \t", $cmax,"\n";
    
    # Input number of CMB PS steps:
    print OUTFILE "NCPS \t",$nsteps, "\n";

    # Estimate PS of Galaxy? (0 - no, 1 - yes):
    print OUTFILE "GALFLAG \t",0, "\n";

    # Write likelihood to screen (0 - no, 1 - yes):
    print OUTFILE "PRINTFLAG \t", 0, "\n";

    # Write likelihood to a file (0 - no, 1 - yes):
    print OUTFILE "WRITEFLAG \t",$writeflag, "\n";

    if ($writeflag == 1) {
	# Output filename for likelihood :
	print OUTFILE "LIKEFILE \t",$outprefix[0]."_".$ranseed."_".$simno."_".$uvcells[$cellno].$c[$usenoise].$c[$shiftpos].$c[$mirror].".like", "\n";
    }


    # Use semiexact version (1) or not (0):
    print OUTFILE "SEMIEXACT \t",$semiexact, "\n";

    # Recalculate integrals (0), store integrals in memory (1) or save to disk for further iterations (2):
    print OUTFILE "STOREFLAG \t",2, "\n";

    # Run until converged (1) or single iteration first (0):
    print OUTFILE "CONVERGE \t",1, "\n";

    # Set initial power spectrum (1) or use defaults (0):
    print OUTFILE "INITIALPS \t", 0, "\n";
    
    # Read beam profile from file (0) or use Gaussian (1):
    # print OUTFILE $gaussian_beam, "\n";

    # Restart
    #for ($i = 0; $i <  $niter-1; $i++) {
    #	print OUTFILE 1, "\n";
    #}
    #print OUTFILE 0, "\n";


    close OUTFILE;
    system(@args);
}

