#!/usr/bin/perl

# plot simulations using likeplot program
# Klaus Maisinger, Sep-2001

$runcmd="nice -10";
$madcowpath="../madcow/";
$executable=$madcowpath."f77/likeplot";
$tmpfile="likeplot.input";

my $ranseed=345;
my @outprefix = ( "VSA1", "VSA1A", "VSA1B" );
my $nfields=3;
my $nsim=1;

# bin_vis parameters
my @uvcells=(2,3,4);
my $cellno=0;
my $usenoise=1;
my $shiftpos=1;
my $mirror=1;
my @c=("n","y");
my $ps_suffix=".ps";
my $like_suffix=".like";


# loop over fields, gridding, and random simulations
$cellmax=@uvcells;
for ($fieldno = 0; $fieldno < $nfields; $fieldno++) {
    for ($cellno = 0; $cellno < $cellmax; $cellno++) {
	for ($simno = 1; $simno <= $nsim; $simno++) {
	    my $prefix;

	    # set filenames
	    $prefix = $outprefix[0]."_".$ranseed."_".$simno."_".$uvcells[$cellno].$c[$usenoise].$c[$shiftpos].$c[$mirror];
	    $psfile = $prefix.$ps_suffix;
	    $likefile = $prefix.$like_suffix;

	    # generate input and call likeplot program
	    run_likeplot();
	}
    }
    
    # use next field; make previous field last element of the list
    $tmp = shift @outprefix;
    push @outprefix, $tmp;
}


sub run_likeplot() {
    my $i, $j;
    my @args=("/bin/sh","-tc",
	      $runcmd." ".$executable." < ".$tmpfile);

    if (!(-e $executable)) {
	die "Executable ",$executable," does not exist.\n";
    }

    open(OUTFILE, ">".$tmpfile);

    # Graphics device/type (? to see list, default /xwin):
    print OUTFILE $psfile."/PS", "\n";

    # Enter filename of likelihood function:
    print OUTFILE $likefile, "\n";

    # Are parameter points equally spaced (y/n)? [y]
    print OUTFILE "y",  "\n";
    
    # Interpolate PS onto (finer) regular grid (y/n)? [n] 
    print OUTFILE "n",  "\n";
    
    # Combine bins (y/n) [n]? 
    print OUTFILE "n",  "\n";
    
    # Are PS axes C_l (0) or l^2 C_l/2pi (1)?
    print OUTFILE 1, "\n";

    # Multiply likelihood by Jeffreys prior (y/n)? [n]: 
    print OUTFILE "n",  "\n";

    # Input the number of axes to marginalise:
    print OUTFILE 0, "\n";
    
    # Write out ML power in each bin (y/n)? [n]:
    print OUTFILE "n",  "\n";

    # Do you want a 1-D or 2-D plot? 
    print OUTFILE 2, "\n";

    # Which axes do you want to plot? 
    print OUTFILE 1, " ", 3, "\n";

    # Interpolate onto a finer grid (y/n)? [n] 
    print OUTFILE "n",  "\n";

    #  Plot greyscale (y/n)? [n] 
    print OUTFILE "y",  "\n";

    # Plot confidence contours (y/n)? [n] 
    print OUTFILE "n",  "\n";

    # Write out the 2-D array to a file (y/n)? [n] 
    print OUTFILE "n",  "\n";

    #  Plot different axes (y/n)? [n] 
    print OUTFILE "n",  "\n";

    #  Marginalise different axes (y/n)? [n]
    print OUTFILE "n",  "\n";

    # Open new plot device (y/n)? [n]
    print OUTFILE "n",  "\n";

    close OUTFILE;
    system(@args);
}

